@@ -89,6 +89,7 @@ def write_kafka_stream(stream: DataFrame, spark_job_conf: dict, output_name):
             .start() \
             .awaitTermination()
     elif output_conf.get("once") is not None:
+        print(f'You choose to write into kafka stream with trigger.once={output_conf.get("once")}')
         stream \
             .writeStream \
             .format("kafka") \
@@ -214,6 +215,7 @@ def write_delta_stream(spark_job_conf: dict, output_name: str, stream: DataFrame
             .start(output_stream_conf['delta_options']['location']) \
             .awaitTermination()
     elif output_stream_conf.get('once') is not None:
+        print(f'You choose to write into delta stream with trigger.once={output_stream_conf.get("once")}')
         stream \
             .writeStream \
             .format("delta") \
